@@ -18,6 +18,7 @@ import sys
 import argparse
 import logging
 from typing import Optional, Sequence, List, Dict, Iterable, Union, cast, Tuple
+
 from typing_extensions import TypedDict
 
 from numpy import rint
@@ -142,6 +143,21 @@ class RunList(QtWidgets.QTreeWidget):
         self.itemSelectionChanged.connect(self.selectRun)
         self.itemActivated.connect(self.activateRun)
 
+        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.customContextMenuRequested.connect(self.copy_to_clipboard)
+
+    @Slot(QtCore.QPoint)
+    def copy_to_clipboard(self, position: QtCore.QPoint) -> None:
+        menu = QtWidgets.QMenu()
+        copy_icon = self.style().standardIcon(QtWidgets.QStyle.SP_DialogSaveButton)
+        copy_action = menu.addAction(copy_icon, "Copy")
+        action = menu.exec_(self.mapToGlobal(position))
+        if action == copy_action:
+            model_index = self.indexAt(position)
+            item = self.itemFromIndex(model_index)
+            QtWidgets.QApplication.clipboard().setText(item.text(
+                model_index.column()))
+
     def addRun(self, runId: int, **vals: str) -> None:
         lst = [str(runId)]
         lst.append(vals.get('experiment', ''))
