@@ -1,9 +1,9 @@
-from typing import Dict, Any, Callable
+from typing import Dict, Any, Callable, Optional, Type
 
 from .. import QtGui, QtWidgets
 from .node import Node, NodeWidget, updateOption
 
-connectCallableType = Callable[['AutoNodeGuiTemplate', str, Dict[str, Any], bool], None]
+connectCallableType = Callable[['AutoNodeGuiTemplate', str, Dict[str, Any], bool], QtWidgets.QWidget]
 
 
 class AutoNodeGuiTemplate(NodeWidget):
@@ -14,7 +14,7 @@ def connectIntegerSpinbox(
         gui: AutoNodeGuiTemplate,
         optionName: str,
         specs: Dict[str, Any],
-        confirm: bool):
+        confirm: bool) -> QtWidgets.QSpinBox:
 
     widget = QtWidgets.QSpinBox()
     widget.setValue(specs.get('initialValue', 1))
@@ -30,7 +30,7 @@ def connectFloatSpinbox(
         gui: AutoNodeGuiTemplate,
         optionName: str,
         specs: Dict[str, Any],
-        confirm: bool):
+        confirm: bool) -> QtWidgets.QDoubleSpinBox:
 
     widget = QtWidgets.QDoubleSpinBox()
     widget.setValue(specs.get('initialValue', 1))
@@ -50,48 +50,50 @@ class AutoNodeGui(AutoNodeGuiTemplate):
         float: connectFloatSpinbox,
     }
 
-    def __init__(self, parent=None, node=None):
+    def __init__(self, parent: Optional[QtWidgets.QWidget] = None,
+                 node: Optional[Node] = None):
         super().__init__(parent)
-        self.layout = QtWidgets.QFormLayout()
-        self.setLayout(self.layout)
+        layout = QtWidgets.QFormLayout()
+        self.setLayout(layout)
 
-    def addOption(self, name: str, specs: Dict[str, Any], confirm: bool):
+    def addOption(self, name: str, specs: Dict[str, Any], confirm: bool) -> None:
         optionType = specs.get('type', None)
         widget = None
         func = self.widgetConnection.get(optionType, None)
         if func is not None:
             widget = func(self, name, specs, confirm)
 
-        self.layout.addRow(name, widget)
+        self.layout().addRow(name, widget)
 
-    def addConfirm(self):
+    def addConfirm(self) -> None:
         widget = QtWidgets.QPushButton('Confirm')
         widget.pressed.connect(self.signalAllOptions)
-        self.layout.addRow('', widget)
+        self.layout().addRow('', widget)
 
 
 class AutoNode(Node):
 
-    def addOption(self, name, specs):
+    def addOption(self, name: str, specs: Dict[str, Any]) -> None:
         varname = '_' + name
         setattr(self, varname, specs.get("initialValue", None))
 
-        def getter(self):
+        def getter(self: AutoNode) -> Any:
             return getattr(self, varname)
 
         @updateOption(name)
-        def setter(self, val):
+        def setter(self: AutoNode, val: str) -> None:
             setattr(self, varname, val)
 
         setattr(self.__class__, name, property(getter, setter))
 
 
-def autonode(nodeName, confirm=True, **options):
+def autonode(nodeName: str, confirm: bool = True, **options: Any) -> Callable:
 
-    def decorator(func):
+    def decorator(func: Callable) -> Type["AutoNode"]:
 
         class AutoNodeGui_(AutoNodeGui):
-            def __init__(self, parent=None, node=None):
+            def __init__(self, parent: Optional[QtWidgets.QWidget] = None,
+                         node: Optional[Node] = None):
                 super().__init__(parent)
                 for optName, optSpecs in options.items():
                     self.addOption(optName, optSpecs, confirm=confirm)
@@ -99,7 +101,7 @@ def autonode(nodeName, confirm=True, **options):
                     self.addConfirm()
 
         class AutoNode_(AutoNode):
-            def __init__(self, name):
+            def __init__(self, name: str):
                 super().__init__(name)
                 for optName, optSpecs in options.items():
                     self.addOption(optName, optSpecs)
@@ -107,7 +109,7 @@ def autonode(nodeName, confirm=True, **options):
         AutoNode_.__name__ = nodeName
         AutoNode_.nodeName = nodeName
         AutoNode_.nodeOptions = options
-        AutoNode_.process = func
+        AutoNode_.process = func  # type: ignore[assignment]
         AutoNode_.useUi = True
         AutoNode_.uiClass = AutoNodeGui_
 
